ChildPod<TParent extends Object, TChild extends Object> class final

Inheritance
Mixed-in types
Available extensions

Constructors

ChildPod({required TPodsResponderFn<TParent> responder, required TValuesReducerFn<TChild, TParent> reducer})

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isDisposed bool
Whether dispose has been called.
no setterinherited
onAfterDispose ↔ void Function()?
getter/setter pairinherited
parents Iterable<GenericPod<TParent>>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ↔ TChild
The current value of the object.
getter/setter pairoverride

Methods

addListener(VoidCallback listener) → void
❌ Do not add listeners to this Pod directly.
inherited
addSingleExecutionListener(VoidCallback listener) → void
❌ Do not add listeners to this Pod directly.
inherited
addStrongRefListener({required VoidCallback strongRefListener}) → void
❌ Do not add listeners to this Pod directly.
inherited
asChildPod<TParent extends Object>() ChildPod<TParent, T>

Available on ValueListenable<T>, provided by the ValueListenableExt extension

Casts the ValueListenable to a ChildPod.
asDisposablePod() DisposablePod<T>

Available on ValueListenable<T>, provided by the ValueListenableExt extension

Casts the ValueListenable to a DisposablePod.
asGenericPod() GenericPod<T>

Available on ValueListenable<T>, provided by the ValueListenableExt extension

Casts the ValueListenable to a GenericPod.
asProtectedPod() ProtectedPod<T>

Available on ValueListenable<T>, provided by the ValueListenableExt extension

Casts the ValueListenable to a ProtectedPod.
asRootPod() RootPod<T>

Available on ValueListenable<T>, provided by the ValueListenableExt extension

Casts the ValueListenable to a RootPod.
asSharedPod<TRawValue extends Object>() SharedPod<T, TRawValue>

Available on ValueListenable<T>, provided by the ValueListenableExt extension

Casts the ValueListenable to a SharedPod.
asValueListenable() ValueListenable<T>

Available on ValueListenable<T>, provided by the ValueListenableExt extension

Returns the Pod as a ValueListenable.
cond(bool test(TChild value)) Resolvable<TChild>
Returns the value of the Pod when the test returns true.
inherited
dispose() → void
Disposes this ValueListenable. Successive calls to this method will be ignored.
override
disposeChildren() → void
Disposes and removes all children.
inherited
getValue() → TChild
inherited
map<B extends Object>(B reducer(TChild value)) ChildPod<TChild, B>
Maps this GenericPod to a new ChildPod using the specified reducer.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
pinListener(VoidCallback listener) → void
Holds listener alive until unpinListener is called or this notifier is disposed. Intended for callers that pass addStrongRefListener a closure they themselves do not retain.
inherited
reduce<C extends Object, O extends Object>(GenericPod<O> other, TReducerFn2<C, TChild, O> reducer) ChildPod<Object, C>
Reduces the current Pod and other into a single ChildPod.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited
unpinListener(VoidCallback listener) → void
Releases the strong reference taken by pinListener. Safe to call when no pin exists.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited