mapToAsync method
Converts every Resolvable in the iterable to an Async.
Implementation
@pragma('vm:prefer-inline')
Iterable<Async<T>> mapToAsync() => map((e) => e.toAsync());
Converts every Resolvable in the iterable to an Async.
@pragma('vm:prefer-inline')
Iterable<Async<T>> mapToAsync() => map((e) => e.toAsync());