whereErr method

Map<K, Err<V>> whereErr()

Creates a new map containing only the entries where the value is an Err. The values in the new map are instances of Err<V>.

Implementation

Map<K, Err<V>> whereErr() => Map.fromEntries(
      entries
          .where((e) => e.value.isErr())
          .map((e) => MapEntry(e.key, e.value.err().unwrap())),
    );