whereOk method

Map<K, Ok<V>> whereOk()

Creates a new map containing only the entries where the value is an Ok. The values in the new map are instances of Ok<V>.

Implementation

Map<K, Ok<V>> whereOk() => Map.fromEntries(
      entries
          .where((e) => e.value.isOk())
          .map((e) => MapEntry(e.key, e.value.ok().unwrap())),
    );