innerPods property
Returns the current list of inner pods to subscribe to. Identity is
significant — the builder uses identical() to diff against the
previous subscription set.
Implementation
final List<Listenable> Function() innerPods;
Returns the current list of inner pods to subscribe to. Identity is
significant — the builder uses identical() to diff against the
previous subscription set.
final List<Listenable> Function() innerPods;