detach method

void detach()

Detach from the finalizer so the pod will NOT be auto-disposed when the wrapper is GC'd. Use this to transfer ownership back to a caller that will dispose manually.

Implementation

void detach() => _finalizer.detach(this);