flatMap<R extends Object> abstract method

Resolvable<R> flatMap<R extends Object>(
  1. @noFutures Resolvable<R> noFutures(
    1. T value
    )
)

Chains another Resolvable-producing operation: the monadic bind for Resolvable. If this is in an Err state, the chain short-circuits with that Err. If noFutures throws, the throw is absorbed into an Err.

Equivalent to .then(...) followed by .flatten(), with the short-circuit and throw-absorption wired in.

Implementation

Resolvable<R> flatMap<R extends Object>(
  @noFutures Resolvable<R> Function(T value) noFutures,
);