update method
Updates the current value of the Pod via updateValue and calls
notifyListeners if the returned value is different from the current
value.
No-op on a disposed pod (see set).
Implementation
void update(
T Function(T oldValue) updateValue, {
bool notifyImmediately = true,
}) {
if (isDisposed) return;
final newValue = updateValue(value);
_set(newValue, notifyImmediately: notifyImmediately);
}