ServiceState enum
Full lifecycle state for a ServiceMixin. Each lifecycle phase has three
substates: _ATTEMPT (listeners running), _SUCCESS (all listeners ran
cleanly), and _ERROR (at least one listener errored).
Values
- NOT_INITIALIZED → const ServiceState
- RUN_ATTEMPT → const ServiceState
- RUN_SUCCESS → const ServiceState
- RUN_ERROR → const ServiceState
- PAUSE_ATTEMPT → const ServiceState
- PAUSE_SUCCESS → const ServiceState
- PAUSE_ERROR → const ServiceState
- RESUME_ATTEMPT → const ServiceState
- RESUME_SUCCESS → const ServiceState
- RESUME_ERROR → const ServiceState
- DISPOSE_ATTEMPT → const ServiceState
- DISPOSE_SUCCESS → const ServiceState
- DISPOSE_ERROR → const ServiceState
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isNotInitialized → bool
-
trueonly when the service has not yet been initialized.no setter - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
didDispose(
) → bool -
trueif the service is in any of the DISPOSE substates. Oncetrue, the service is terminal — no further lifecycle transitions are allowed. -
didPause(
) → bool -
trueif the service is in any of the PAUSE substates. -
didResume(
) → bool -
trueif the service is in any of the RESUME substates. -
didRun(
) → bool -
trueif the service is in any of the RUN substates (attempt / success / error). -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ServiceState> - A constant List of the values in this enum, in order of their declaration.