didPause method
true if the service is in any of the PAUSE substates.
Implementation
bool didPause() => [
ServiceState.PAUSE_ATTEMPT,
ServiceState.PAUSE_SUCCESS,
ServiceState.PAUSE_ERROR,
].contains(this);
true if the service is in any of the PAUSE substates.
bool didPause() => [
ServiceState.PAUSE_ATTEMPT,
ServiceState.PAUSE_SUCCESS,
ServiceState.PAUSE_ERROR,
].contains(this);