didResume method
true if the service is in any of the RESUME substates.
Implementation
bool didResume() => [
ServiceState.RESUME_ATTEMPT,
ServiceState.RESUME_SUCCESS,
ServiceState.RESUME_ERROR,
].contains(this);
true if the service is in any of the RESUME substates.
bool didResume() => [
ServiceState.RESUME_ATTEMPT,
ServiceState.RESUME_SUCCESS,
ServiceState.RESUME_ERROR,
].contains(this);