didRun method
true if the service is in any of the RUN substates
(attempt / success / error).
Implementation
bool didRun() => [
ServiceState.RUN_ATTEMPT,
ServiceState.RUN_SUCCESS,
ServiceState.RUN_ERROR,
].contains(this);
true if the service is in any of the RUN substates
(attempt / success / error).
bool didRun() => [
ServiceState.RUN_ATTEMPT,
ServiceState.RUN_SUCCESS,
ServiceState.RUN_ERROR,
].contains(this);