isNotInitialized property
bool
get
isNotInitialized
true only when the service has not yet been initialized.
Implementation
bool get isNotInitialized => this == ServiceState.NOT_INITIALIZED;
true only when the service has not yet been initialized.
bool get isNotInitialized => this == ServiceState.NOT_INITIALIZED;