UserEntity class final

Group entity recommended for user-specific dependencies (preferences, per-user state). Backs DI.user.

Inheritance

Constructors

UserEntity()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → int
The value associated with this Entity instance.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isDefault() → bool
inherited
isNotDefault() → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preferOverDefault(Entity other) → Entity
Returns other if this is DefaultEntity, otherwise returns this.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited