run property
The function to invoke when the operation is run.
For cross-isolate transport, this must be a top-level or static
function — closures capture frame state and are not sendable.
Implementation
final FutureOr<T> Function() run;
The function to invoke when the operation is run.
For cross-isolate transport, this must be a top-level or static
function — closures capture frame state and are not sendable.
final FutureOr<T> Function() run;