get<T extends Component> method
Reads the component of type T from entity, or None if absent.
Implementation
Option<T> get<T extends Component>(WorldEntity entity) =>
_readComponent<T>(entity);
Reads the component of type T from entity, or None if absent.
Option<T> get<T extends Component>(WorldEntity entity) =>
_readComponent<T>(entity);