has<T extends Component> method
Whether this entity has a component of type T.
Implementation
bool has<T extends Component>() => world._hasComponent<T>(this);
Whether this entity has a component of type T.
bool has<T extends Component>() => world._hasComponent<T>(this);