handleDetachedState method
Return true to have the service dispose when the app enters
AppLifecycleState.detached. Defaults to false (opt-in).
Implementation
@visibleForOverriding
bool handleDetachedState() => false;
Return true to have the service dispose when the app enters
AppLifecycleState.detached. Defaults to false (opt-in).
@visibleForOverriding
bool handleDetachedState() => false;