readEvents<E extends Event> method

Iterable<E> readEvents<E extends Event>()

Returns the events of type E sent so far this (outer) tick. Filters the flat buffer by is E, so derived events are visible via base-typed readers and vice-versa is correctly excluded.

Implementation

Iterable<E> readEvents<E extends Event>() sync* {
  for (final e in _eventBuffer) {
    if (e is E) yield e;
  }
}